article nav {
  padding: 6px 0;
  margin: 6px 0;
  border-bottom: 1px #eee solid;
}

article.markdown-body {
  min-width: 200px;
  max-width: 790px;
  margin: 0 auto;
  padding: 30px;
  border: 1px solid #ddd;
  border-radius: 3px;
  word-wrap: break-word;
}
